@@ -18,7 +18,7 @@
 //! use pca9539::expander::PCA9539;
 //! use pca9539::expander::PinID::Pin1;
 //!
-//! let i2c_bus = DummyI2CBus::new();
+//! let i2c_bus = DummyI2CBus::default();
 //! let mut  expander = PCA9539::new(i2c_bus, 0x74);
 //! let pins = expander.pins();
 //! ```
@@ -33,7 +33,7 @@
 //!# use pca9539::expander::PinID::{Pin1, Pin2, Pin4};
 //!# use embedded_hal::digital::v2::{InputPin, IoPin, PinState, OutputPin};
 //!#
-//!# let i2c_bus = DummyI2CBus::new();
+//!# let i2c_bus = DummyI2CBus::default();
 //!# let mut  expander = PCA9539::new(i2c_bus, 0x74);
 //! let pins = expander.pins();
 //! let pin12 = pins.get_pin(Bank1, Pin2);
@@ -61,8 +61,9 @@
 //!# use pca9539::expander::PCA9539;
 //!# use pca9539::expander::PinID::{Pin0, Pin1, Pin2, Pin3, Pin4};
 //!# use embedded_hal::digital::v2::{InputPin, IoPin, PinState, OutputPin};
+//!# use pca9539::pins::RefreshableInputPin;
 //!#
-//!# let i2c_bus = DummyI2CBus::new();
+//!# let i2c_bus = DummyI2CBus::default();
 //!# let mut  expander = PCA9539::new(i2c_bus, 0x74);
 //! let pins = expander.pins();
 //! let pin00 = pins.get_refreshable_pin(Bank0, Pin0);
@@ -85,8 +86,9 @@
 //!# use pca9539::expander::PCA9539;
 //!# use pca9539::expander::PinID::{Pin0, Pin1, Pin2, Pin3, Pin4};
 //!# use embedded_hal::digital::v2::{InputPin, IoPin, PinState, OutputPin};
+//!# use pca9539::pins::RefreshableOutputPin;
 //!#
-//!# let i2c_bus = DummyI2CBus::new();
+//!# let i2c_bus = DummyI2CBus::default();
 //!# let mut  expander = PCA9539::new(i2c_bus, 0x74);
 //! let pins = expander.pins();
 //! let mut pin00 = pins.get_refreshable_pin(Bank0, Pin0).into_output_pin(PinState::Low).unwrap();
@@ -118,7 +120,7 @@
 //!# use pca9539::example::DummyI2CBus;
 //!# use pca9539::expander::PCA9539;
 //!#
-//!# let i2c_bus = DummyI2CBus::new();
+//!# let i2c_bus = DummyI2CBus::default();
 //!# let mut  expander = PCA9539::new(i2c_bus, 0x74);
 //! let pins = expander.pins();
 //! ```
@@ -133,7 +135,7 @@
 //!# use pca9539::example::DummyI2CBus;
 //!# use pca9539::expander::PCA9539;
 //!#
-//!# let i2c_bus = DummyI2CBus::new();
+//!# let i2c_bus = DummyI2CBus::default();
 //!# let mut  expander = PCA9539::new(i2c_bus, 0x74);
 //!# #[cfg(feature = "cortex-m")]
 //! let pins = expander.pins_cs_mutex();
@@ -151,7 +153,7 @@
 //!# use pca9539::example::DummyI2CBus;
 //!# use pca9539::expander::PCA9539;
 //!#
-//!# let i2c_bus = DummyI2CBus::new();
+//!# let i2c_bus = DummyI2CBus::default();
 //!# let mut  expander = PCA9539::new(i2c_bus, 0x74);
 //!# #[cfg(feature = "spin")]
 //! let pins = expander.pins_spin_mutex();
@@ -161,6 +163,8 @@ use crate::guard::RefGuard;
 use core::marker::PhantomData;
 use embedded_hal::blocking::i2c::{Read, Write};
 
+pub use crate::pin_refreshable::{RefreshableInputPin, RefreshableOutputPin};
+
 /// Container for fetching individual pins
 pub struct Pins<B: Write + Read, R: RefGuard<B>> {
     guard: R,
